(function ($) {

    $(document).ready( function() {

		cu_window_manager.initialize();

	});

	// A class to manage window resizer and scroller functions
	var cu_window_manager = {

		// Manual Configs
		resizerLatency : 40, // in milliseconds. Higher = less CPU, lower = faster UI 

		// Automagic Configs (changed by the script)
		useTransitions		: true, 
		useParallax			: true,
		cannotAutoplayVideo : false, 

		// Vars to initialize
		resizeTimeout 	: null, 
		windowWidth		: null,
		windowHeight	: null,
		scrollTop		: null,
		scrollBot		: null,
		getVars			: null,

		initialize : function() {

			// Check device type
			var i = 0,
				is_iOS = false,
				iDevice = ['iPad', 'iPhone', 'iPod'];
			for ( ; i < iDevice.length ; i++ ) {
				if( navigator.platform === iDevice[i] ){ is_iOS = true; break; }
			}
			var ua = navigator.userAgent.toLowerCase();
			var is_Android = ua.indexOf("android") > -1; //&& ua.indexOf("mobile");

			// Determine if this device cannot autoplay HTML5 video
			if (is_Android || is_iOS) {
				cu_window_manager.cannotAutoplayVideo = true;
				cu_window_manager.useTransitions = true;
			}

			if(!(/Android|iPhone|iPad|iPod|BlackBerry|Windows Phone/i).test(navigator.userAgent || navigator.vendor || window.opera)){ 
				cu_window_manager.useParallax = true;
				cu_parallax_fx.setupFX();

			} else {
				cu_window_manager.useParallax = false;
			}

			// Set up window change events
			if (window.addEventListener) {
				window.addEventListener('scroll', cu_window_manager.scroller, false);
				window.addEventListener('resize', cu_window_manager.resizer, false);
			} else if (window.attachEvent) {
				window.attachEvent('onscroll', cu_window_manager.scroller);
				window.attachEvent('onresize', cu_window_manager.resizer);
			}

			// Intial vars
			cu_window_manager.scrollTop 	= $(window).scrollTop();
			cu_window_manager.windowWidth 	= $(window).width();
			cu_window_manager.windowHeight 	= $(window).height();


		}, // end initialize


		/***************************************************
		* The purpose of the resizer function is to act as a buffer to prevent rapid execution of the functions which must run on window resize. 
		* By using a timetout, we can reduce the number of times these functions are called to increase browser performance. 
		***************************************************/
		resizer : function() {

			if (cu_window_manager.resizeTimeout != null) {
				clearTimeout(cu_window_manager.resizeTimeout);
			}
			cu_window_manager.resizeTimeout = setTimeout(function() {
				cu_window_manager.resizeTimeout = null; 

				// Update vars
				cu_window_manager.windowWidth = $(window).width();
				cu_window_manager.windowHeight = $(window).height();

				// FUNCTIONS TO FIRE ON RESIZE HERE:
				cu_hero_area.adjustVideoSize();

			}, cu_window_manager.resizerLatency); 

		}, // end resizer

		scroller : function() {

			// Update vars
			cu_window_manager.scrollTop = $(window).scrollTop();
			cu_window_manager.scrollBot = cu_window_manager.scrollTop + cu_window_manager.windowHeight;
			
			// FUNCTIONS TO FIRE ON SCROLL HERE:
			if (cu_window_manager.useParallax) cu_parallax_fx.process();

		} // end scroller

	} // end cu_window_manager


	// Contains the animation FX 
	var cu_parallax_fx = {

		enabled	: false, // starts false
		skrollr : null,

		admissionStartPX 			: null,
		admissionAnimationReady		: false,
		$undergraduateAdmission 	: null,

		graduateAdmissionStartPX 		: null,
		graduateAdmissionAnimationReady	: false,
		$graduateAdmission 				: null,


		// Prep the elements by hiding them as needed. Run only once. 
		setupFX : function() {

			/*
			* Undergraduate Admission
			*************************/
			this.$undergraduateAdmission = $("#undergraduateAdmission");	
			this.admissionStartPX = this.$undergraduateAdmission.find('.statistics').offset().top;

			this.$undergraduateAdmission.find('.fade-elem').css('opacity', 0); // prep for fade in

			/*
			* Graduate Admission
			*************************/
			this.$graduateAdmission = $("#graduateAdmission");
			this.graduateAdmissionStartPX = this.$graduateAdmission.offset().top;

			this.process(); // in case we already scrolled
		},

		// Re-run as needed. 
		enable : function() {

			// DO ENABLE TASKS
			try {

				// Do not initialize Skrollr on mobile. 
				if(!(/Android|iPhone|iPad|iPod|BlackBerry|Windows Phone/i).test(navigator.userAgent || navigator.vendor || window.opera)){
					cu_parallax_fx.skrollr = skrollr.init();
				}

			} catch (e) {
				// No Skrollr support
			}

			this.graduateAdmissionAnimationReady = true;
			this.admissionAnimationReady = true;

			cu_parallax_fx.enabled = true;
		},

		// Re-run as needed. 
		disable : function() {
			// DO DISABLE TASKS
			cu_parallax_fx.skrollr.destroy();
			cu_parallax_fx.enabled = false;

			this.$graduateAdmission.css('background-size','');
		},

		// Fire on scroll to position elements
		process : function() {

			if (!cu_parallax_fx.enabled && cu_window_manager.windowWidth > 640) {
				cu_parallax_fx.enable();
			} else if (cu_parallax_fx.enabled && cu_window_manager.windowWidth < 640) {
				cu_parallax_fx.disable();
			}

			if (!cu_parallax_fx.enabled) return false;

			/*
			* Undergraduate Admission | number counter
			*************************/
			if (this.admissionAnimationReady && cu_window_manager.scrollBot > this.admissionStartPX ) {
				this.animateAdmissionNumbers();

				this.$undergraduateAdmission.find('.fade-elem').each(function(i) {
					var $elem = $(this);
					setTimeout(function() {
						$elem.animate({'opacity':'1'}, 1000, 'linear');
					}, 600 * i);
				});

				this.admissionAnimationReady = false;
			} 

			/*
			* Graduate Admission | ken burns
			*************************/
			// if (this.graduateAdmissionAnimationReady && cu_window_manager.scrollBot > this.graduateAdmissionStartPX ) {

			// 	// this.kenBurns(this.$graduateAdmission);
			// 	this.graduateAdmissionAnimationReady = false;
			// } 

			if (cu_window_manager.scrollTop < 100) {
				// Reset the animation if the user goes to the top. 
				this.graduateAdmissionAnimationReady = true;
				this.admissionAnimationReady = true;
			}

		},

		/***************************************************
		* Ken burns FX for BG image of element
		***************************************************/
		kenBurns : function($elem) {

			// Do not fire if frame is already visible
			if ($elem.css('background-size') == '100%' ) {
				$elem.animate({'background-size':'120%'}, 10000, "swing");
			} else {
				$elem.css('background-size', '120%');
				$elem.animate({'background-size':'100%'}, 10000, "swing");
			}

		},

		animateAdmissionNumbers : function() {

			this.$undergraduateAdmission.find(".statistics").find("li").each(function(i) {

				var $label = $(this).find('.label');
				var $bigstat = $(this).find('.bigstat');

				$bigstat.css('opacity', 0);
				$label.css('opacity', 0);

				setTimeout(function() {
					cu_parallax_fx.animateSingleNumber($bigstat);

					$bigstat.animate({opacity:1}, 600);
					$label.animate({opacity:1}, 400);

				}, 100 * Math.floor((Math.random()*10)+1));
				
			});

		}};
			});
				